@@ -1,11 +1,8 @@
 from __future__ import unicode_literals
 from collections import defaultdict
 from itertools import chain, groupby
+from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
-try:
-    from django.contrib.contenttypes.fields import GenericForeignKey
-except ImportError:  # Django < 1.9 pragma: no cover
-    from django.contrib.contenttypes.generic import GenericForeignKey
 from django.conf import settings
 from django.contrib.admin.models import LogEntry
 from django.core import serializers
@@ -64,12 +61,7 @@ class Revision(models.Model):
     )
 
     def get_comment(self):
-        try:
-            return LogEntry(change_message=self.comment).get_change_message()
-        except AttributeError:
-            # Django < 1.10
-            # LogEntry dont have `.get_change_message()`
-            return self.comment
+        return LogEntry(change_message=self.comment).get_change_message()
 
     def revert(self, delete=False):
         # Group the models by the database of the serialized model.
@@ -278,7 +270,7 @@ class Version(models.Model):
             field = model._meta.get_field(field_name)
             if isinstance(field, models.ManyToManyField):
                 # M2M fields with a custom through are not stored in m2m_data, but as a separate model.
-                if field.attname in object_version.m2m_data:
+                if object_version.m2m_data and field.attname in object_version.m2m_data:
                     field_dict[field.attname] = object_version.m2m_data[field.attname]
             else:
                 field_dict[field.attname] = getattr(obj, field.attname)
